/*
 * LazyImporter jEdit Plugin (DirElement.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.classpath;

import java.io.File;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.gjt.sp.util.Log;

/**
 * A "directory" class path element. For example: "D:\classes".
 */ 
public class DirElement extends ClassPathElement
{
  public DirElement(String elementString, int position)
  {
    super(elementString, position);
  }
  
  protected void loadClasses()
  {
    // regardless of whether or not the following operation passes or fails,
    // we should at least initialize the class map
    mPackageClassMap = new HashMap();
    mClassPackageMap = new HashMap();
    
    try {
      // get the name and attempt 
      File file = new File(getName());

      if (file.isDirectory()) {
        findClassesInDirectories(file, file);
      }
      
    } catch (Exception e) {
      Log.log(Log.MESSAGE, DirElement.class, "[LazyImporter Plugin]: could not find " + getName() + " specified in classpath, ignoring.");
    } 
  }

  private void findClassesInDirectories(File baseDirectory, File directory) 
  {
    // see if there are any subdirectories
    File[] fileList = directory.listFiles();
    
    // determine current package
    String baseDirectoryString = baseDirectory.getAbsolutePath();
    String currentDirectoryString = directory.getAbsolutePath();
    String currentPackage = currentDirectoryString.substring(baseDirectoryString.length());
        
    currentPackage = convertPathPackageToDotPackage(currentPackage);
    
    // if the current package string is zero length - it means this class has
    // no package, so we need to set it to the NO_PACKAGE_MARKER package
    currentPackage = (currentPackage.length() > 0 ? currentPackage : NO_PACKAGE_MARKER);
    
    // for each subdirectory, recursively call this method
    for (int i = 0; i < fileList.length; i++) {
      // if the current file is a directory call method recursively
      if (fileList[i].isDirectory()) {
        findClassesInDirectories(baseDirectory, fileList[i]);
      } else {
        // must be a file, so if it is a class file, then add it to the map
        String fileName = fileList[i].getName().toLowerCase();
        if (fileName.endsWith(".class")) {
          // get the list if it exists for this package
          List classList = (List) mPackageClassMap.get(currentPackage);
          if (classList == null) {
            classList = new ArrayList();
            mPackageClassMap.put(currentPackage, classList);
          }
          
          // remove the .class from the end (ie. find last dot)
          String classLessFileName = fileList[i].getName().substring(0, fileList[i].getName().lastIndexOf('.'));
          classList.add(classLessFileName);
          
          // now add class to the class package map
          List packageList = (List) mClassPackageMap.get(classLessFileName);
          if (packageList == null) {
            packageList = new ArrayList();
            mClassPackageMap.put(classLessFileName, packageList);
          }
          packageList.add(currentPackage);
          
        }
      }
    }
  }

  private String convertPathPackageToDotPackage(String pathPackage)
  {
    char pathSeparatorChar = File.separatorChar;
    String dotPackage = pathPackage.replace(pathSeparatorChar, '.'); 
    
    if (pathPackage.length() > 0) {
      return dotPackage.substring(1);
    }
    
    return dotPackage;
  }
 
}
