/*
 * LazyImporter jEdit Plugin (JarFileElement.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.classpath;

import java.io.File;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

import org.gjt.sp.util.Log;

/**
 * Represents a Jar (*.jar/*.zip) element in a class path. (eg. D:\libraries\jEdit.jar)
 */
public class JarFileElement extends ClassPathElement
{
  public JarFileElement(String elementString, int position)
  {
    super(elementString, position);
  }
  
  protected void loadClasses()
  {
    // regardless of whether or not the following operation passes or fails,
    // we should at least initialize the class list
    mPackageClassMap = new HashMap();
    mClassPackageMap = new HashMap();
    
    try {
      // get the name and attempt 
      File file = new File(getName());
      findClassesInJAR(new ZipFile(file));
    } catch (Exception e) {
      Log.log(Log.MESSAGE, JarFileElement.class, "[LazyImporter Plugin]: could not find " + getName() + " specified in classpath, ignoring.");
    }
  }
  
  
  private void findClassesInJAR(ZipFile jarFile) 
  {
    Enumeration zipFileEntries = jarFile.entries();
    
    while (zipFileEntries.hasMoreElements()) {
      ZipEntry zipEntry = (ZipEntry) zipFileEntries.nextElement();
                  
      // if it is a class file, then extract the package name and add it to the
      // class map
      String entryName = zipEntry.getName();
      if (!zipEntry.isDirectory() && entryName.toLowerCase().endsWith(".class")) {
        // remove the .class from the end of the name
        entryName = entryName.substring(0, entryName.lastIndexOf('.'));
        
        // find the package name                
        int lastDot = entryName.lastIndexOf("/");
        if (lastDot >= 0) {
          String packageName = entryName.substring(0, lastDot).replace('/', '.');
          String className = entryName.substring(lastDot + 1).replace('$', '.');
          
          // get the list if it exists for this package
          List classList = (List) mPackageClassMap.get(packageName);
          if (classList == null) {
            classList = new ArrayList();
            mPackageClassMap.put(packageName, classList);
          }
          classList.add(className);
          
          // now add class to the class package map
          List packageList = (List) mClassPackageMap.get(className);
          if (packageList == null) {
            packageList = new ArrayList();
            mClassPackageMap.put(className, packageList);
          }
          packageList.add(packageName);
        }
      }
    }
  }
    
}
