/*
 * LazyImporter jEdit Plugin (ImportListWindow.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;

import javax.swing.border.BevelBorder;
import javax.swing.BorderFactory;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.jedit.View;

/**
 * Simple window (frame) shown when the class path is being loaded.
 */
public class InitialLoadingFrame extends JFrame
{
  private View mParentView;
  
  public InitialLoadingFrame(View view)
  {
    mParentView = view;
    
    init();
  }
  
  //
  // Private Helper Methods
  //
  
  private void init()
  {
    getContentPane().setLayout(new BorderLayout());

    // make this JFrame undecorated (ie. remove funky top-right stuff)
    setUndecorated(true);
    
    JPanel placer = new JPanel(new BorderLayout());
    placer.setBorder(BorderFactory.createCompoundBorder(
      BorderFactory.createLineBorder(Color.lightGray), 
      BorderFactory.createBevelBorder(BevelBorder.RAISED, Color.lightGray, Color.darkGray)));
    placer.add(createLabelPanel());
    
    getContentPane().add(placer);
    pack();
    
    // position in center of view
    Dimension viewSize = mParentView.getSize();
    setLocation( (int) mParentView.getLocationOnScreen().getX() + ((viewSize.width - getSize().width) / 2),
     (int) mParentView.getLocationOnScreen().getY() + ((viewSize.height - getSize().height) / 2));
      
    setVisible(true);
  } 

  private JPanel createLabelPanel()
  {
    JPanel labelPanel = new JPanel(new BorderLayout());
    labelPanel.setBorder(BorderFactory.createEmptyBorder(6,6,6,6));
    labelPanel.add(new JLabel(jEdit.getProperty("LazyImporter.InitialLoading.Message")));
    return labelPanel;
  }   
  
}
