/*
 * LazyImporter jEdit Plugin (ClassImportStatement.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer;

/**
 * Represents an individual class import statement (ie. not a wildcard import).
 * For example: "import java.io.File".
 */
public class ClassImportStatement extends ImportStatement
{
  // the class name being imported in this statement.
  private String mClassName;
  
  /**
   * Construct a class import statement.
   *
   * @param packageName the dot-separated package import string.
   * @param className the class name being imported.
   */
  public ClassImportStatement(String packageName, String className)
  {
    super(packageName);
    
    mClassName = className;
  }
  
  public String getClassName()
  {
    return mClassName;
  }
  
  public String getFullyQualifiedClassName()
  {
    return getPackageName() + "." + getClassName();
  }
  
  public boolean equals(Object object)
  {
    if (object == null) {
      return false;
    }
    
    if (!(object instanceof ClassImportStatement)) {
      return false;
    }
    
    ClassImportStatement compareTo = (ClassImportStatement) object;
    return compareTo.getFullyQualifiedClassName().equals(getFullyQualifiedClassName());
  }
  
  public String getActualImportStatement()
  {
    return "import " + getFullyQualifiedClassName();
  }
  
  /**
   * toString() method for debugging
   */
  public String toString()
  {
    return getFullyQualifiedClassName();
  }
}
