/*
 * LazyImporter jEdit Plugin (ImportStatement.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer;

/**
 * Represents an import statement in a piece of java code.
 * (ie. import java.util.*, or import java.util.File).
 */
public abstract class ImportStatement
{
  // the package statement being imported (ie. java.util, or java.lang)
  private String mPackageString;
  
  public ImportStatement(String packageString)
  {
    mPackageString = packageString;
  }
  
  public String getPackageName()
  {
    return mPackageString;
  }
  
  public abstract String getActualImportStatement();
   
  /**
   * Static factory method to create the appropriate ImportStatement
   *
   * @param importStatement the import statement. (should be in the form
   * "java.lang.*"  or "java.util.Date").
   */
  public static ImportStatement create(String importString)
  {
    // if there is a ';' on the end, remove it and trim the string
    if (importString.endsWith(";")) {
      importString = importString.substring(0, importString.lastIndexOf(';')).trim();
    }
    
    // if there is an "import" at the front then remove it
    if (importString.startsWith("import")) {
      importString = importString.substring(importString.indexOf("import") + 6).trim();
    }
    
    // if there is a "package" at the front then remove it and add .* to the end
    if (importString.startsWith("package")) {
      importString = importString.substring(importString.indexOf("package") + 8).trim() + ".*";
    }
    
    if (importString.endsWith("*")) {
      String packageMinusWildcard = 
        importString.substring(0, importString.lastIndexOf('.'));
      return new PackageImportStatement(packageMinusWildcard);
    }
    
    // else, must be a class import (ie. java.util.Date)
    String packageName = importString.substring(0, importString.lastIndexOf('.'));
    String className = importString.substring(importString.lastIndexOf(".")+1);
    return new ClassImportStatement(packageName, className);
  }
}
