/*
 * LazyImporter jEdit Plugin (PackageImportStatement.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer;

/**
 * Represents a wildcard (or package) import statement.  These imports import
 * all the classes in a particular java package as they are required.
 * For example: "import java.io.*". 
 */
public class PackageImportStatement extends ImportStatement
{
  /**
   * Construct a package import statement.
   *
   * @param packageName the dot-separated package name of the import.
   */
  public PackageImportStatement(String packageName)
  {
    super(packageName);
  }
  
  public boolean equals(Object object)
  {
    if (object == null) {
      return false;
    }
    
    if (!(object instanceof PackageImportStatement)) {
      return false;
    }
    
    PackageImportStatement compareTo = (PackageImportStatement) object;
    return compareTo.getPackageName().equals(getPackageName());
  }

  
  public String getActualImportStatement()
  {
    return "import " + getPackageName() + ".*";
  }
  
  /**
   * toString() method for debugging
   */
  public String toString()
  {
    return getPackageName();
  }
}
