/*
 * LazyImporter jEdit Plugin (ManualGroupingDrawingStrategy.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.drawing;

import java.util.Iterator;
import java.util.List;

import org.etheridge.lazyimporter.importer.drawing.DrawingStrategy;
import org.etheridge.lazyimporter.importer.grouping.ImportGroupElement;
import org.etheridge.lazyimporter.importer.grouping.ImportGroupElementFactory;
import org.etheridge.lazyimporter.importer.JavaClass;

/**
 * Draws the ImportStatements in "groups" specified by the user.
 */
public class ManualGroupingDrawingStrategy implements DrawingStrategy
{
  private List mElementList;
  
  /**
   * Constructor.
   *
   * @param groupingString string that represents a stringified version
   * of the manual grouping strategy.
   */
  public ManualGroupingDrawingStrategy(String groupingString)
  {
    mElementList = ImportGroupElementFactory.createElementsFromString(groupingString);
  }
  
  public String drawImports(JavaClass javaClass, List importStatements)
  {
    StringBuffer buffer = new StringBuffer();
 
    for (Iterator i = mElementList.iterator(); i.hasNext();) {
      ImportGroupElement configurationElement = (ImportGroupElement) i.next();
      buffer.append(configurationElement.draw(importStatements, mElementList));
    }

    // remove any trailing spaces (these are ignored) and return the string
    return buffer.substring(0, buffer.lastIndexOf(";") + 1);
  }
}
