/*
 * LazyImporter jEdit Plugin (AllRemainingImportGroupElement.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.grouping;

import java.lang.String;
import java.lang.StringBuffer;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.etheridge.lazyimporter.importer.grouping.FilteringImportGroupElement;
import org.etheridge.lazyimporter.importer.grouping.ImportGroupElement;
import org.etheridge.lazyimporter.importer.ImportStatement;

/**
 * An import grouping element that represents all imports not specifically 
 * configured. (through a PrefixImportGroupElement, for example)
 */
public class AllRemainingImportGroupElement implements ImportGroupElement
{
  public static final String STRING_REPRESENTATION = "*";
  
  private static AllRemainingImportGroupElement mSingletonInstance;
  
  public static synchronized AllRemainingImportGroupElement getInstance()
  {
    if (mSingletonInstance == null) {
      mSingletonInstance = new AllRemainingImportGroupElement();
    }
    return mSingletonInstance;
  }
  
  private AllRemainingImportGroupElement()
  {
  }
  
  public String toString()
  {
    return STRING_REPRESENTATION;
  }
  
  public String draw(List importStatements, List overallConfiguration)
  {
    // make a copy of the import statement list
    List filteredImportStatements = new ArrayList(importStatements);
    
    // iterate through overall configuration elements, and filter out any
    // that match
    for (Iterator i = overallConfiguration.iterator(); i.hasNext();) {
      ImportGroupElement element = (ImportGroupElement) i.next();
      if (element instanceof FilteringImportGroupElement) {
        FilteringImportGroupElement filteringElement =
          (FilteringImportGroupElement) element;
        for (Iterator j = filteredImportStatements.iterator(); j.hasNext();) {
          if (filteringElement.doesImportMatch((ImportStatement)j.next())) {
            j.remove();
          }
        }
      } 
    }

    // draw the remaining import statements in the list       
    StringBuffer buffer = new StringBuffer();
    for (Iterator i = filteredImportStatements.iterator(); i.hasNext();) {
      ImportStatement currentImportStatement = (ImportStatement) i.next();
      buffer.append(currentImportStatement.getActualImportStatement() + ";\n");
    }
    return buffer.toString();
  }
}
