/*
 * LazyImporter jEdit Plugin (CommentImportGroupElement.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.etheridge.lazyimporter.importer.grouping;

import java.io.File;

import java.util.List;

import org.etheridge.lazyimporter.importer.ImportStatement;

/**
 * Represents a blank line in an import grouping configuration.
 */
public class CommentImportGroupElement implements ImportGroupElement
{
  public static final String STRING_REPRESENTATION = "COMMENT:";
  
  private String mComment;
  
  public CommentImportGroupElement(String comment)
  {
    // if this is a string representation then make sure we remove the prefix
    if (comment.indexOf(STRING_REPRESENTATION) >= 0) {
      int index = comment.indexOf(STRING_REPRESENTATION);
      comment = comment.substring(index + STRING_REPRESENTATION.length());
    }
    
    // we do not want the file separator char in here, so replace it with 
    // a character.
    comment.replace(File.pathSeparatorChar, '-');
    
    mComment = comment;
  }
  
  public String toString()
  {
    return STRING_REPRESENTATION + mComment;
  }
  
  public String draw(List importStatements, List overallConfiguration)
  {
    return "// " + mComment + System.getProperty("line.separator");
  }
}
