/*
 * LazyImporter jEdit Plugin (ImportGroupElement.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.etheridge.lazyimporter.importer.grouping;

import java.util.List;

import org.etheridge.lazyimporter.importer.ImportStatement;

/**
 * An ImportGroupElement represents a single element in an import grouping
 * configuration.  Examples of ImportGroupElements include:
 * <ul>
 *   <li> java.* </li>
 *   <li> <BLANK LINE> </li>
 *   <li> comment - (ie. "java imports" </li>
 *   <li> * (all remaining imports) </li>
 * </ul>
 */
public interface ImportGroupElement
{
  /**
   * Force overriding of toString().
   */
  public String toString();
  
  /**
   * Draws the specified import statements according to this ImportGroupElement's
   * configuration rules.
   *
   * @param importStatements the statements to draw.
   * @param overallConfiguration list of all ImportGroupElements (NOTE: because of
   * the AllRemainingImportGroupElement, this is required.. kinda crap, but ok).
   * @return a string representation of the specified import statements 
   * according to this configuration element.
   */
  public String draw(List importStatements, List overallConfiguration);
}
