/*
 * LazyImporter jEdit Plugin (ImportGroupElementFactory.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.grouping;

import java.io.File;

import java.lang.StringBuffer;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import java.util.StringTokenizer;

/**
 * Simple factory to create ImportGroupElements
 */
public class ImportGroupElementFactory
{
  public static ImportGroupElement createFromString(String string)
  {
    if (BlankLineImportGroupElement.STRING_REPRESENTATION.equals(string)) {
      return new BlankLineImportGroupElement();
    } else if (AllRemainingImportGroupElement.STRING_REPRESENTATION.equals(string)) {
      return AllRemainingImportGroupElement.getInstance();
    } else if (string.startsWith(CommentImportGroupElement.STRING_REPRESENTATION)) {
      return new CommentImportGroupElement(string);
    } else {
      return new PrefixImportGroupElement(string);
    }
  }
  
  public static List createElementsFromString(String string)
  {
    // list to return
    List list = new ArrayList();
    
    // tokenizer string
    StringTokenizer tokenizer = 
      new StringTokenizer(string, String.valueOf(File.pathSeparator));
    
    // if there are no tokens yet, then insert the "*"
    // import
    if (!tokenizer.hasMoreTokens()) {
      list.add(AllRemainingImportGroupElement.getInstance());
    }
    
    while (tokenizer.hasMoreTokens()) {
      list.add(createFromString(tokenizer.nextToken()));
    }
    
    return list;
  }
  
  public static String createElementString(Enumeration elements)
  {
    StringBuffer buffer = new StringBuffer();
    while (elements.hasMoreElements()) {
      buffer.append(elements.nextElement());
      if (elements.hasMoreElements()) {
        buffer.append(File.pathSeparator);
      }
    }
    return buffer.toString();
  }
}
