/*
 * LazyImporter jEdit Plugin (PrefixImportGroupElement.java) 
 *  
 * Copyright (C) 2004 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.grouping;

import java.lang.StringBuffer;

import java.util.Iterator;
import java.util.List;

import org.etheridge.lazyimporter.importer.ImportStatement;

/**
 * Represents a import grouping element that is configured based upon its 
 * prefix. (ie. java.*, com, etc..)
 */
public class PrefixImportGroupElement implements FilteringImportGroupElement
{
  private String mPrefix;
  
  public PrefixImportGroupElement(String importPrefix)
  {
    mPrefix = importPrefix;
  }
  
  public String toString()
  {
    return mPrefix;
  }
  
  public boolean doesImportMatch(ImportStatement statement)
  {
    return statement.getPackageName().startsWith(mPrefix);
  }
  
  public String draw(List importStatements, List overallConfiguration)
  {
    StringBuffer buffer = new StringBuffer();
    // iterate through list if import statements, and draw those that 
    // match this prefix
    for (Iterator i = importStatements.iterator(); i.hasNext();) {
     ImportStatement currentImportStatement = (ImportStatement) i.next();
      if (currentImportStatement.getPackageName().startsWith(mPrefix)) {
        buffer.append(currentImportStatement.getActualImportStatement() + ";\n");
      }
    }
    return buffer.toString();
  
  }
}
