/*
 * LazyImporter jEdit Plugin (ImplicitImportsAtTopOrderingStrategy.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.ordering;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.etheridge.lazyimporter.importer.ImportStatement;
import org.etheridge.lazyimporter.importer.JavaClass;

/**
 * Ordering Strategy that puts all implicit (ie. this package's) import 
 * statements at the beginning of the import list.
 */
public class ImplicitImportsAtTopOrderingStrategy implements OrderingStrategy
{
  public List orderImports(JavaClass javaClass, List importStatements)
  {
    // determine the package for this java class
    ImportStatement implicitImportStatement = javaClass.getImplicitImportStatement();

    // if there is an implicit import statement, then move it (if it exists) and
    // any resolved imports to the front of the list.
    if (implicitImportStatement != null) {
      String implicitImportPackage = implicitImportStatement.getPackageName();
      
      // move any resolved implicit imports to the front
      List implicitClassImports = new ArrayList();
      for (Iterator i = importStatements.iterator(); i.hasNext();) {
        ImportStatement currentImportStatement = (ImportStatement) i.next();
        if (currentImportStatement.getPackageName().equals(implicitImportPackage)) {
          // add to implicit class imports list and remove it
          implicitClassImports.add(currentImportStatement);
          i.remove();
        }
      }
      
      // now add any implicit class imports to the front of the import statement
      // list
      importStatements.addAll(0, implicitClassImports);
    }
    
    return importStatements;
  }
} 
 

