/*
 * LazyImporter jEdit Plugin (JavaImportOrderingStrategy.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.ordering;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.etheridge.lazyimporter.importer.ImportStatement;
import org.etheridge.lazyimporter.importer.PackageImportStatement;

/**
 * Parent class of Java import ordering strategies to hold common functionality.
 */
public class JavaImportOrderingStrategy
{
  private static List msJavaImportPrefixes = new ArrayList();
  static {
    msJavaImportPrefixes.add("java.");
    msJavaImportPrefixes.add("javax.");
    msJavaImportPrefixes.add("com.sun.java.");
  }
  
  protected List getJavaImportPrefixes()
  {
    return msJavaImportPrefixes;
  }
  
  /**
   * Removes any java imports from the specified list and returns the java
   * imports.
   * 
   * @param importStatements a list of import statements
   * @return the list of java import statements
   */
  protected List stripJavaImports(List importStatements)
  {
    List javaImports = new ArrayList();
    
    // iterate through import statements and pull out the "java" imports
    for (Iterator i = importStatements.iterator(); i.hasNext();) {
      ImportStatement currentImportStatement = (ImportStatement) i.next();
      String packageName = currentImportStatement.getPackageName();
      
      // if the import statement is a package import statement, re-add the
      // ".*" on the end, so that the package name checking will work 
      // correctly. (Otherwise single java.*, javax.*, com.sun...* imports may
      // not be ordered correctly).
      packageName = (currentImportStatement instanceof PackageImportStatement ?
        packageName + ".*" : packageName);
      
      // if the start of this package name is any of the known "java" imports
      // then remove it and add to separate list.
      for (Iterator j = msJavaImportPrefixes.iterator(); j.hasNext();) {
        if (packageName.startsWith((String)j.next())) {
          javaImports.add(currentImportStatement);
          i.remove();
          break; // break out of the for loop
        }
      }
    }
    
    return javaImports;
  }
}
