/*
 * LazyImporter jEdit Plugin (OrderingStrategy.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.importer.ordering;

import java.util.List;

import org.etheridge.lazyimporter.importer.JavaClass;

/**
 * The Ordering strategy to be used to define the order the import statements
 * are written back to the java class code.
 */
public interface OrderingStrategy
{
  /**
   * Reorders the list in some way.
   * 
   * @param javaClass the javaclass whose imports are being sorted.
   * @param importStatements the list of imports to reorder.
   * @return the reordered list.
   */
  public List orderImports(JavaClass javaClass, List importStatements);
}
