/*
 * LazyImporter jEdit Plugin (ClassPathOptionsPane.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
package org.etheridge.lazyimporter.options;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.GridLayout;

import java.io.File;

import java.lang.Integer;
import java.lang.Math;
import java.lang.NumberFormatException;
import java.lang.String;
import java.lang.StringBuffer;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.filechooser.FileFilter;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import org.etheridge.lazyimporter.ClassPathManager;
import org.etheridge.lazyimporter.LazyImporterProperties;

import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;

/**
 * A pane that contains visual components that allow the user to set the 
 * OpenIt plugin settings.
 */
public class ClassPathOptionsPane extends AbstractOptionPane
  implements ActionListener   
{
  // gui components for user defined classpath section
  private JTextArea mUserDefinedClassPathTextArea;
  private JButton mChooseJarZipFilesButton;
  
  // gui components for rt.jar section
  private JRadioButton mDoNotUseRTRadioButton;
  private JRadioButton mUseAutoDetectedRTRadioButton;
  private JRadioButton mUseUserSpecifiedRTRadioButton;
  private JTextField mUserSpecifiedRTJarTextField;
  
  // gui components for polling interval section
  private JTextField mPollingIntervalTextField;
  
  // File Chooser
  private static JFileChooser msJarZipFileChooser;
   
  public ClassPathOptionsPane()
  {
    super("LazyImporter.ClassPathOptionPane");
  }
  
	public void _init() 
  {
    setLayout(new BorderLayout());
    
    JPanel placerPanel = new JPanel(new BorderLayout());
    placerPanel.add(createUserDefinedClassPathPanel(), BorderLayout.CENTER);

    JPanel bottomPlacerPanel = new JPanel(new BorderLayout());
    bottomPlacerPanel.add(createAddRuntimeJarPanel(), BorderLayout.CENTER);
    bottomPlacerPanel.add(createPollingIntervalPanel(), BorderLayout.SOUTH);
    placerPanel.add(bottomPlacerPanel, BorderLayout.SOUTH);

    add(placerPanel, BorderLayout.NORTH);
	}
    
  public void _save()
  {
    if (propertiesHaveChanged()) {
      setProperties();
      ClassPathManager.getInstance().refreshClassPath();
    }
  }
  
  //
  // GUI Initialization
  //
  
  private JPanel createUserDefinedClassPathPanel()
  {
    JPanel userDefinedClassPathPanel = new JPanel(new BorderLayout(6,6));
    userDefinedClassPathPanel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.ClassPathOptionPane.UserDefinedClassPath.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
   
    // text to explain what to put here
    JLabel instructionLabel = new JLabel(jEdit.getProperty("LazyImporter.ClassPathOptionPane.UserDefinedClassPathInstructions"));
    userDefinedClassPathPanel.add(instructionLabel, BorderLayout.NORTH);
    
    // text area for user-defined classpath textarea
    mUserDefinedClassPathTextArea = new JTextArea();
    mUserDefinedClassPathTextArea.setRows(10);
    mUserDefinedClassPathTextArea.setText(jEdit.getProperty(LazyImporterProperties.USER_DEFINED_CLASSPATH_STRING, ""));
    mUserDefinedClassPathTextArea.setCaretPosition(0);
    mUserDefinedClassPathTextArea.setLineWrap(true);
    userDefinedClassPathPanel.add(new JScrollPane(mUserDefinedClassPathTextArea), BorderLayout.CENTER);
    
    // add the button panel to the south
    userDefinedClassPathPanel.add(createButtonPanel(), BorderLayout.SOUTH);
    
    return userDefinedClassPathPanel;
  }
  
  private JPanel createButtonPanel()
  {
    JPanel buttonPanel = new JPanel(new BorderLayout(6,6));
    
    mChooseJarZipFilesButton = new JButton
      (jEdit.getProperty("LazyImporter.ClassPathOptionPane.SelectFilesButtonText"));
    mChooseJarZipFilesButton.addActionListener(this);
    buttonPanel.add(mChooseJarZipFilesButton, BorderLayout.WEST);
    buttonPanel.add(new JLabel
      (jEdit.getProperty("LazyImporter.ClassPathOptionPane.SelectFilesDescription")));
       
    return buttonPanel;
  }
  
  private JPanel createAddRuntimeJarPanel()
  {
    JPanel addRuntimeJarPanel = new JPanel(new GridLayout(3,1,6,6));
    addRuntimeJarPanel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.ClassPathOptionPane.RTJar.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
    
    // radio buttons in group
    mDoNotUseRTRadioButton = new JRadioButton(jEdit.getProperty("LazyImporter.ClassPathOptionPane.DoNotUseRT"));
    mDoNotUseRTRadioButton.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_DO_NOT_USE, true));
    mUseAutoDetectedRTRadioButton = new JRadioButton(jEdit.getProperty("LazyImporter.ClassPathOptionPane.UseAutoDetectedRT") + ClassPathManager.getInstance().getRTJarFile().getAbsolutePath()); // TODO - this should probably not be done in the event thread!  Use a swing worker instead.
    mUseAutoDetectedRTRadioButton.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_AUTO_DETECTED, false));
        
    // User-specified RT.jar panel
    JPanel userSpecifiedRTPanel = new JPanel(new BorderLayout(6,6));
    mUseUserSpecifiedRTRadioButton = new JRadioButton(jEdit.getProperty("LazyImporter.ClassPathOptionPane.UseUserSpecifiedRT"));
    mUseUserSpecifiedRTRadioButton.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED, false));
    mUserSpecifiedRTJarTextField = new JTextField();
    mUserSpecifiedRTJarTextField.setText(jEdit.getProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED_STRING));
    userSpecifiedRTPanel.add(mUseUserSpecifiedRTRadioButton, BorderLayout.WEST);
    userSpecifiedRTPanel.add(mUserSpecifiedRTJarTextField, BorderLayout.CENTER);

    // add radio buttons to button group
    ButtonGroup group = new ButtonGroup();
    group.add(mDoNotUseRTRadioButton);
    group.add(mUseAutoDetectedRTRadioButton);
    group.add(mUseUserSpecifiedRTRadioButton);
    
    // add to panel
    addRuntimeJarPanel.add(mDoNotUseRTRadioButton);
    addRuntimeJarPanel.add(mUseAutoDetectedRTRadioButton);
    addRuntimeJarPanel.add(userSpecifiedRTPanel);
    
    return addRuntimeJarPanel;
  }
  
  private JPanel createPollingIntervalPanel()
  {
    JPanel pollingIntervalPanel = new JPanel(new BorderLayout());
    pollingIntervalPanel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.ClassPathOptionPane.ClassPathReadRate.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
    
    JLabel instructionLabel = new JLabel(jEdit.getProperty("LazyImporter.ClassPathOptionPane.ClassPathReadRateInstruction"));
    pollingIntervalPanel.add(instructionLabel, BorderLayout.WEST);
    
    mPollingIntervalTextField = new JTextField(String.valueOf(jEdit.getIntegerProperty(LazyImporterProperties.CLASSPATH_POLLING_INTERVAL, ClassPathManager.DEFAULT_POLLING_INTERVAL)));
    mPollingIntervalTextField.setColumns(5);
    pollingIntervalPanel.add(mPollingIntervalTextField, BorderLayout.CENTER);
        
    return pollingIntervalPanel;
  }

  private boolean propertiesHaveChanged()
  {
    String currentUserDefinedClassPath = jEdit.getProperty(LazyImporterProperties.USER_DEFINED_CLASSPATH_STRING, "");
    if (!currentUserDefinedClassPath.equals(mUserDefinedClassPathTextArea.getText()) ||
        jEdit.getIntegerProperty(LazyImporterProperties.CLASSPATH_POLLING_INTERVAL, ClassPathManager.DEFAULT_POLLING_INTERVAL) != getPollingIntervalValue() ||        
        jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_DO_NOT_USE, false) != mDoNotUseRTRadioButton.isSelected() ||
        jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_AUTO_DETECTED, false) != mUseAutoDetectedRTRadioButton.isSelected() ||
        jEdit.getBooleanProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED, false) != mUseUserSpecifiedRTRadioButton.isSelected() ||
        !jEdit.getProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED_STRING, "").equals(mUserSpecifiedRTJarTextField.getText())) {
      return true;
    }
    return false;
  }
  
  private void setProperties()
  {
    jEdit.setProperty(LazyImporterProperties.USER_DEFINED_CLASSPATH_STRING, mUserDefinedClassPathTextArea.getText());
    jEdit.setBooleanProperty(LazyImporterProperties.RTJAR_DO_NOT_USE, mDoNotUseRTRadioButton.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.RTJAR_AUTO_DETECTED, mUseAutoDetectedRTRadioButton.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED, mUseUserSpecifiedRTRadioButton.isSelected());
    jEdit.setProperty(LazyImporterProperties.RTJAR_USER_SPECIFIED_STRING, mUserSpecifiedRTJarTextField.getText());
    jEdit.setIntegerProperty(LazyImporterProperties.CLASSPATH_POLLING_INTERVAL, getPollingIntervalValue());
  }
  
  private int getPollingIntervalValue()
  {
    // attempt to convert the string entered in the text field to an integer 
    try {
      int pollingInterval = Integer.parseInt(mPollingIntervalTextField.getText());
      return Math.max(ClassPathManager.MINIMUM_POLLING_INTERVAL, pollingInterval);
    } catch (NumberFormatException nfe) {
      // if we get a number format exception, then just return the current
      // value set in the property
      return jEdit.getIntegerProperty(LazyImporterProperties.CLASSPATH_POLLING_INTERVAL, 
        ClassPathManager.DEFAULT_POLLING_INTERVAL);
    }
  }
  
  //
  // ActionListener interface implementation
  //
  
  
  public void actionPerformed(ActionEvent ae) 
  {
    // user pressed the choose jar/zip/directory button
    if (ae.getSource() == mChooseJarZipFilesButton) {
    
      // lazily create file chooser
      if (msJarZipFileChooser == null) {
        msJarZipFileChooser = new JFileChooser();
        msJarZipFileChooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
        msJarZipFileChooser.setMultiSelectionEnabled(true);
        msJarZipFileChooser.setApproveButtonText(jEdit.getProperty
          ("LazyImporter.ClassPathOptionPane.FileChooser.ApproveButtonText"));
        msJarZipFileChooser.setDialogTitle(jEdit.getProperty
          ("LazyImporter.ClassPathOptionPane.FileChooser.Title"));
        msJarZipFileChooser.setFileFilter(new ClassPathElementFileFilter());
      }
      
      // get the persisted directory string, and use this to set the directory
      // on the file chooser (if the directory exists).
      File currentDirectory = new File(jEdit.getProperty
        (LazyImporterProperties.LAST_OPENED_FILE_CHOOSER_DIRECTORY, ""));
      if (currentDirectory.exists()) {
        msJarZipFileChooser.setCurrentDirectory(currentDirectory);
      }
             
      int returnVal = msJarZipFileChooser.showOpenDialog(jEdit.getActiveView());
      if (returnVal == JFileChooser.APPROVE_OPTION) {
        // get the current directory and persist it as a property
        jEdit.setProperty(LazyImporterProperties.LAST_OPENED_FILE_CHOOSER_DIRECTORY, 
          msJarZipFileChooser.getCurrentDirectory().getAbsolutePath());
        
        // get the file(s) selected from the file chooser
        File[] selectedFiles = msJarZipFileChooser.getSelectedFiles();
        
        // if there were no files selected, just return and do nothing
        if (selectedFiles.length == 0) {
          return;
        }

        StringBuffer buffer = new StringBuffer(mUserDefinedClassPathTextArea.getText());
        
        // if there are currently files in the classpath, see if we need a
        // path separator before the new files
        if (mUserDefinedClassPathTextArea.getText().trim().length() > 0) {
          if (!mUserDefinedClassPathTextArea.getText().trim().endsWith(File.pathSeparator)) {
            buffer.append(File.pathSeparator);
          }
        }
                
        // add each file's absolute file to the END of the class path string
        for (int i = 0; i < selectedFiles.length; i++) {
          buffer.append(selectedFiles[i].getAbsolutePath() + File.pathSeparator);
        }
        
        // add the buffer's text into the classpath text box
        mUserDefinedClassPathTextArea.setText(buffer.toString());
      }
    } 
  }
 
  //
  // Inner Classes
  //
  
  private class ClassPathElementFileFilter extends FileFilter
  {
    public boolean accept(File f)
    {
      return f.isDirectory() || 
        f.getName().toLowerCase().endsWith(".jar") ||
        f.getName().toLowerCase().endsWith(".zip");
    }
    
    public String getDescription()
    {
      return jEdit.getProperty("LazyImporter.ClassPathOptionPane.FileChooser.FilterString");
    }
  }
}
