/*
 * LazyImporter jEdit Plugin (MiscellaneousOptionsPane.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.options;

import java.awt.BorderLayout;
import java.awt.GridLayout;

import javax.swing.BorderFactory;
import javax.swing.JCheckBox;
import javax.swing.JPanel;

import org.etheridge.lazyimporter.LazyImporterProperties;

import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;

/**
 * LazyImporter Miscellaneous options
 */
public class MiscellaneousOptionsPane extends AbstractOptionPane   
{
  private JCheckBox mDisplayCurrentPackageImportCheckBox;
  private JCheckBox mDoNotPopupWindowOnSingleImportMatchCheckBox;

  public MiscellaneousOptionsPane()
  {
    super("LazyImporter.MiscellaneousOptionPane");
  }
  
	public void _init() 
  {
    setLayout(new BorderLayout());
    
    JPanel topLevelPlacer = new JPanel(new GridLayout(2,1,6,6));
    topLevelPlacer.add(createMiscellanousOptionsPanel());
    topLevelPlacer.add(createPopupImportWindowPanel());
    
    add(topLevelPlacer, BorderLayout.NORTH);
	}
    
  public void _save()
  {
    setProperties();
  }
  
  //
  // GUI Initialization
  //
  
  private JPanel createMiscellanousOptionsPanel()
  {
    JPanel miscOptionsPanel = new JPanel(new BorderLayout());
    miscOptionsPanel.setBorder(BorderFactory.createCompoundBorder
      (BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.MiscellaneousOptionPane.MiscellaneousOptions.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
   
    mDisplayCurrentPackageImportCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.MiscellaneousOptionPane.DisplayCurrentPackageImports"));
    mDisplayCurrentPackageImportCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.MISC_DISPLAY_CURRENT_PACKAGE_IMPORTS, false));
    miscOptionsPanel.add(mDisplayCurrentPackageImportCheckBox);
       
    return miscOptionsPanel;
  }
  
  private JPanel createPopupImportWindowPanel()
  {
    JPanel popupWindowPanel = new JPanel(new BorderLayout());
    popupWindowPanel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.MiscellaneousOptionPane.ImportWindow.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));

    mDoNotPopupWindowOnSingleImportMatchCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.MiscellaneousOptionPane.DoNotPopupWindowOnSingleMatch"));
    mDoNotPopupWindowOnSingleImportMatchCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.MISC_DO_NOT_POPUP_WINDOW_ON_SINGLE_MATCH, false));
    popupWindowPanel.add(mDoNotPopupWindowOnSingleImportMatchCheckBox);
       
    return popupWindowPanel;
  }
  
  private void setProperties()
  {
    jEdit.setBooleanProperty(LazyImporterProperties.MISC_DISPLAY_CURRENT_PACKAGE_IMPORTS, mDisplayCurrentPackageImportCheckBox.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.MISC_DO_NOT_POPUP_WINDOW_ON_SINGLE_MATCH, mDoNotPopupWindowOnSingleImportMatchCheckBox.isSelected());
  }
 
}

