/*
 * LazyImporter jEdit Plugin (OrderingOptionsPane.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.options;

import java.awt.BorderLayout;
import java.awt.GridLayout;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import org.etheridge.lazyimporter.LazyImporterProperties;

import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;

/**
 * LazyImporter Ordering options
 */
public class OrderingOptionsPane extends AbstractOptionPane   
{
  private JCheckBox mSortAlphabeticallyCheckBox;
  private JCheckBox mCurrentPackageImportsAtTop;
  
  // java imports
  private JCheckBox mJavaImportsAtTopOrBottomCheckBox;
  private JRadioButton mJavaImportsAtTopRadioButton;
  private JRadioButton mJavaImportsAtBottomRadioButton;
    
  public OrderingOptionsPane()
  {
    super("LazyImporter.OrderingOptionPane");
  }
  
	public void _init() 
  {
    setLayout(new BorderLayout());
    JPanel placerPanel = new JPanel(new BorderLayout(6,6));
    placerPanel.add(createGeneralOrderingPanel(), BorderLayout.NORTH);
    placerPanel.add(createJavaImportsPanel(), BorderLayout.CENTER);
    
    add(placerPanel, BorderLayout.NORTH);
	}
    
  public void _save()
  {
    setProperties();
  }
  
  //
  // GUI Initialization
  //
  
  private JPanel createGeneralOrderingPanel()
  {
    JPanel orderingPathPanel = new JPanel(new GridLayout(2,1,6,6));
    orderingPathPanel.setBorder(BorderFactory.createCompoundBorder
      (BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.OrderingOptionPane.GeneralOrdering.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
   
    // add checkboxes
    mSortAlphabeticallyCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.OrderingOptionPane.SortImportsAlphabetically"));
    mSortAlphabeticallyCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.SORTING_SORT_ALPHABETICALLY, false));
    
    mCurrentPackageImportsAtTop = new JCheckBox(jEdit.getProperty("LazyImporter.OrderingOptionPane.CurrentPackageImportsAtTop"));
    mCurrentPackageImportsAtTop.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.SORTING_CURRENT_PACKAGE_IMPORTS_AT_TOP, false));
   
    // add to panel
    orderingPathPanel.add(mSortAlphabeticallyCheckBox);
    orderingPathPanel.add(mCurrentPackageImportsAtTop);
    
    return orderingPathPanel;
  }
  
  private JPanel createJavaImportsPanel()
  {
    JPanel javaImportsPanel = new JPanel(new GridLayout(3,1,6,6));
    javaImportsPanel.setBorder(BorderFactory.createCompoundBorder
      (BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.OrderingOptionPane.JavaImportOrdering.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
       
    mJavaImportsAtTopOrBottomCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.OrderingOptionPane.SeparateJavaImports"));
    mJavaImportsAtTopOrBottomCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_EXTREMITIES, false));
    mJavaImportsAtTopOrBottomCheckBox.addChangeListener(new ChangeListener()
    {
      public void stateChanged(ChangeEvent e)
      {
        mJavaImportsAtTopRadioButton.setEnabled(mJavaImportsAtTopOrBottomCheckBox.isSelected());
        mJavaImportsAtBottomRadioButton.setEnabled(mJavaImportsAtTopOrBottomCheckBox.isSelected());
      }
    });
    
    mJavaImportsAtTopRadioButton = new JRadioButton(jEdit.getProperty("LazyImporter.OrderingOptionPane.JavaImportsAtBeginning"));
    mJavaImportsAtTopRadioButton.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_TOP, false));
    mJavaImportsAtTopRadioButton.setEnabled(mJavaImportsAtTopOrBottomCheckBox.isSelected());
    mJavaImportsAtBottomRadioButton = new JRadioButton(jEdit.getProperty("LazyImporter.OrderingOptionPane.JavaImportsAtEnd"));
    mJavaImportsAtBottomRadioButton.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_BOTTOM, false));
    mJavaImportsAtBottomRadioButton.setEnabled(mJavaImportsAtTopOrBottomCheckBox.isSelected());
    
    ButtonGroup buttonGroup = new ButtonGroup();
    buttonGroup.add(mJavaImportsAtTopRadioButton);
    buttonGroup.add(mJavaImportsAtBottomRadioButton);
    
   
    // add to panel
    javaImportsPanel.add(mJavaImportsAtTopOrBottomCheckBox);
    javaImportsPanel.add(mJavaImportsAtTopRadioButton);
    javaImportsPanel.add(mJavaImportsAtBottomRadioButton);
    
    return javaImportsPanel;
  }
  
  private void setProperties()
  {
    jEdit.setBooleanProperty(LazyImporterProperties.SORTING_SORT_ALPHABETICALLY, mSortAlphabeticallyCheckBox.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.SORTING_CURRENT_PACKAGE_IMPORTS_AT_TOP, mCurrentPackageImportsAtTop.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_EXTREMITIES, mJavaImportsAtTopOrBottomCheckBox.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_TOP, mJavaImportsAtTopRadioButton.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.SORTING_JAVA_IMPORTS_AT_BOTTOM, mJavaImportsAtBottomRadioButton.isSelected());
  }
 
}

