/*
 * LazyImporter jEdit Plugin (QuickImportOptionsPane.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.options;

import java.awt.BorderLayout;
import java.awt.GridLayout;

import javax.swing.BorderFactory;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.etheridge.lazyimporter.LazyImporterProperties;

import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.jEdit;

/**
 * LazyImporter QuickImport options
 */
public class QuickImportOptionsPane extends AbstractOptionPane   
{
  private JCheckBox mResolvePackageImportsCheckBox;
  private JCheckBox mRemoveUnusedImportsCheckBox;
  private JCheckBox mResolveMissingImportsCheckBox;
      
  public QuickImportOptionsPane()
  {
    super("LazyImporter.QuickImportOptionPane");
  }
  
	public void _init() 
  {
    setLayout(new BorderLayout());
    add(createQuickTouchOptionsPanel(), BorderLayout.NORTH);
    
	}
    
  public void _save()
  {
    setProperties();
  }
  
  //
  // GUI Initialization
  //
  
  private JPanel createQuickTouchOptionsPanel()
  {
    JPanel quickTouchOptionsPanel = new JPanel(new GridLayout(4,1,6,6));
    quickTouchOptionsPanel.setBorder(BorderFactory.createCompoundBorder
      (BorderFactory.createTitledBorder(jEdit.getProperty("LazyImporter.QuickImportOptionPane.QuickImportCommands.Title")), BorderFactory.createEmptyBorder(6,6,6,6)));
   
    JLabel label = new JLabel(jEdit.getProperty("LazyImporter.QuickImportOptionPane.InstructionText"));
    mResolvePackageImportsCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.QuickImportOptionPane.ResolvePackageImports"));
    mResolvePackageImportsCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.QUICK_IMPORT_RESOLVE_PACKAGE_IMPORTS, false));
    mRemoveUnusedImportsCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.QuickImportOptionPane.RemoveUnusedImports"));
    mRemoveUnusedImportsCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.QUICK_IMPORT_REMOVE_UNUSED_IMPORTS, false));
    mResolveMissingImportsCheckBox = new JCheckBox(jEdit.getProperty("LazyImporter.QuickImportOptionPane.ResolveMissingImports"));
    mResolveMissingImportsCheckBox.setSelected(jEdit.getBooleanProperty(LazyImporterProperties.QUICK_IMPORT_RESOLVE_MISSING_IMPORTS, false));
    
    quickTouchOptionsPanel.add(label);
    quickTouchOptionsPanel.add(mResolvePackageImportsCheckBox);
    quickTouchOptionsPanel.add(mRemoveUnusedImportsCheckBox);
    quickTouchOptionsPanel.add(mResolveMissingImportsCheckBox);
       
    return quickTouchOptionsPanel;
  }
  
  private void setProperties()
  {
    jEdit.setBooleanProperty(LazyImporterProperties.QUICK_IMPORT_RESOLVE_PACKAGE_IMPORTS, mResolvePackageImportsCheckBox.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.QUICK_IMPORT_REMOVE_UNUSED_IMPORTS, mRemoveUnusedImportsCheckBox.isSelected());
    jEdit.setBooleanProperty(LazyImporterProperties.QUICK_IMPORT_RESOLVE_MISSING_IMPORTS, mResolveMissingImportsCheckBox.isSelected());
  }
 
}

