/*
 * LazyImporter jEdit Plugin (JavaUtilities.java) 
 *  
 * Copyright (C) 2003 Matt Etheridge (matt@etheridge.org)
 * Modifications by Markus Birth (mbirth@webwriters.de)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.etheridge.lazyimporter.utility;

public class JavaUtilities
{
  /**
   * Given some text (hopefully Java code), strip away all line comments 
   * (starting with //) and all block comments (slash-star, star-slash). 
   * 
   * @param text the test to strip the comments from
   * @return the stripped text
   */
  public static String stripJavaComments(String text)
  {
    JavaCommentStripper commentStripper = new JavaCommentStripper(text);
    return commentStripper.stripComments();
  }
  
  public static String removeStringLiterals(String text)
  {
    StringBuffer buffer = new StringBuffer(text);
    
    boolean inString = false;
    // iterate through buffer, replacing string literals with spaces
    int position = 0;
    
    while (position < buffer.length()) {
      if (buffer.charAt(position) == '"') {
        int stringLiteralStart = ++position;
        while (position<buffer.length() && !(buffer.charAt(position) == '"' && buffer.charAt(position-1) != '\\')) {
          position++;
        }
        
        buffer.delete(stringLiteralStart, position);
        // +1 because else we would recognize the closing quotmark as the opening quotmark of a new string
        position = stringLiteralStart+1;
      } else {
        position++;
      }
    }
    
    return buffer.toString();
  }
  
}
